@@ -30,11 +30,6 @@ DISPLAYNAME = "displayName"
 def _MakeEventTraitMap(
     traits: Mapping[str, Any]
 ) -> Dict[str, camera_traits.EventImageGenerator]:
-    if (
-        camera_traits.CameraEventImageTrait.NAME not in traits
-        and camera_traits.CameraClipPreviewTrait.NAME not in traits
-    ):
-        return {}
     event_trait_map: Dict[str, Any] = {}
     for (trait_name, trait) in traits.items():
         if not isinstance(trait, camera_traits.EventImageGenerator):
